Index: gdb/remote-mips.c |
diff --git a/gdb/remote-mips.c b/gdb/remote-mips.c |
index 01f780f2200c0dde96b3518802d385bfd98f8bbf..babbf19407dc780368dc6d1274a4f99f57883c67 100644 |
--- a/gdb/remote-mips.c |
+++ b/gdb/remote-mips.c |
@@ -1537,7 +1537,6 @@ common_open (struct target_ops *ops, char *name, int from_tty, |
enum mips_monitor_type new_monitor, |
const char *new_monitor_prompt) |
{ |
- char *ptype; |
char *serial_port_name; |
char *remote_name = 0; |
char *local_name = 0; |
@@ -1757,7 +1756,7 @@ mips_detach (struct target_ops *ops, char *args, int from_tty) |
static void |
mips_resume (struct target_ops *ops, |
- ptid_t ptid, int step, enum target_signal siggnal) |
+ ptid_t ptid, int step, enum gdb_signal siggnal) |
{ |
int err; |
@@ -1771,7 +1770,7 @@ mips_resume (struct target_ops *ops, |
/* Return the signal corresponding to SIG, where SIG is the number which |
the MIPS protocol uses for the signal. */ |
-static enum target_signal |
+static enum gdb_signal |
mips_signal_from_protocol (int sig) |
{ |
/* We allow a few more signals than the IDT board actually returns, on |
@@ -1779,13 +1778,13 @@ mips_signal_from_protocol (int sig) |
for these signals is widely agreed upon. */ |
if (sig <= 0 |
|| sig > 31) |
- return TARGET_SIGNAL_UNKNOWN; |
+ return GDB_SIGNAL_UNKNOWN; |
- /* Don't want to use target_signal_from_host because we are converting |
+ /* Don't want to use gdb_signal_from_host because we are converting |
from MIPS signal numbers, not host ones. Our internal numbers |
match the MIPS numbers for the signals the board can return, which |
are: SIGINT, SIGSEGV, SIGBUS, SIGILL, SIGFPE, SIGTRAP. */ |
- return (enum target_signal) sig; |
+ return (enum gdb_signal) sig; |
} |
/* Set the register designated by REGNO to the value designated by VALUE. */ |
@@ -1828,7 +1827,6 @@ mips_wait (struct target_ops *ops, |
ULONGEST rpc, rfp, rsp; |
char pc_string[17], fp_string[17], sp_string[17], flags[20]; |
int nfields; |
- int i; |
interrupt_count = 0; |
hit_watchpoint = 0; |
@@ -1839,7 +1837,7 @@ mips_wait (struct target_ops *ops, |
if (!mips_need_reply) |
{ |
status->kind = TARGET_WAITKIND_STOPPED; |
- status->value.sig = TARGET_SIGNAL_TRAP; |
+ status->value.sig = GDB_SIGNAL_TRAP; |
return inferior_ptid; |
} |
@@ -1954,7 +1952,7 @@ mips_wait (struct target_ops *ops, |
is not a normal breakpoint. */ |
if (strcmp (target_shortname, "lsi") == 0) |
{ |
- char *func_name; |
+ const char *func_name; |
CORE_ADDR func_start; |
CORE_ADDR pc = regcache_read_pc (get_current_regcache ()); |
@@ -2384,7 +2382,7 @@ mips_remove_breakpoint (struct gdbarch *gdbarch, |
is the number of hardware breakpoints already installed. This |
implements the target_can_use_hardware_watchpoint macro. */ |
-int |
+static int |
mips_can_use_watchpoint (int type, int cnt, int othertype) |
{ |
return cnt < MAX_LSI_BREAKPOINTS && strcmp (target_shortname, "lsi") == 0; |
@@ -2418,7 +2416,7 @@ calculate_mask (CORE_ADDR addr, int len) |
for a write watchpoint, 1 for a read watchpoint, or 2 for a read/write |
watchpoint. */ |
-int |
+static int |
mips_insert_watchpoint (CORE_ADDR addr, int len, int type, |
struct expression *cond) |
{ |
@@ -2430,7 +2428,7 @@ mips_insert_watchpoint (CORE_ADDR addr, int len, int type, |
/* Remove a watchpoint. */ |
-int |
+static int |
mips_remove_watchpoint (CORE_ADDR addr, int len, int type, |
struct expression *cond) |
{ |
@@ -2443,7 +2441,7 @@ mips_remove_watchpoint (CORE_ADDR addr, int len, int type, |
/* Test to see if a watchpoint has been hit. Return 1 if so; return 0, |
if not. */ |
-int |
+static int |
mips_stopped_by_watchpoint (void) |
{ |
return hit_watchpoint; |